'appHelp                                                            
'  This program is a help authoring program for applications.
'  It actually consists of two modules... one is the authoring program itself which creates a help
'  file, and the other is an include file, named appHelp.inc, which processes the generated help file. 
'  The help file that is created must have an 'ahp' extension, and appHelp.inc must be included with
'  the application.  Both codes are listed here in the same folder.
'------------------------------------------------------------------------------------------------------ 
'Ver 1.01 04/20/2017
' - corrected position of MENU ATTACH statement
' - corrected calling for help file
' - allow F1 to popup menu for appHelp.inc
'Ver 1.02 04/20/2017
' - added default tabSpaces and wordwrap to new and added items 
' - Scroll found text into view for both genHelp.bas & appHelp.inc (used EM_ScrollCaret)
'Ver 1.03 04/23/2017 
' - corrected bug that resulted in zero values of savedIndexes (treeHandles() in showTreeview)
' - corrected bug when exiting program from a changed textbox
' - streamlined program: put 'select first topic' code in openTheFile() and GLOBAL index
' - help file is changed to a modeless dialog and is closed when application is closed               
' - changed coordinate parameters x and y to be ByRef so IsMissing() could be used 
' - added handle of application as an optional ByVal parameter
'Ver 1.05 04/27/2017
' - revised storage format so that arrays are trimmed during save if any deletes have occured
' - no need for global savedIndexes any more 
' - show treeview expanded when data file is opened and select first item with text                   
'Ver 1.06 05/23/2017
' - had to trim ending '\' in beginning folder for DISPLAY SAVEFILE and DISPLAY OPENFILE
' - corrected several minor bugs, mostly concerning new file creation
' - corrected bug associated with assigning wrong tree level to notes 
' - corrected some bugs associated with pasting text from outside source
'Ver 1.07 05/26/2017
' - F1 launches help file and ESC rmoves it
' - call help with the application's handle to show help as modeless window instead of a modal one
' - removed %TVS_SHOWSELALWAYS from treeview style (corrected bkgrnd color problem)
' - corrected bug: focus content without changing it set fileChanged
'ver 1.08 12/09/2019                          
' - added style %MB_TASKMODAL to %IDM_Move msgbox
' - changed search option from "Start from top" to "Whole word"
' - fixed various problems with search routine (interfacing with F2 and ESC)       
' - added menu search item "Find cancel"
' - added file menu item "Help file title"
' - added gap between title and textbox                                       
' - deny editing of found text (using EM_SetReadOnly)
'ver 1.09 06/04/2020
' - corrected save problem when text(index) being edited had not been stored yet (exit save ok)
'------------------------------------------------------------------------------------------------------
              
%IDD_DIALOG1      =  100
%IDC_Treeview     =  101
%IDC_Title        =  102
%IDC_Gap          =  103                            
%IDC_Textbox      =  104
%IDC_Splitbar     =  105
%IDC_VertLine     =  106                                
%IDC_Statusbar    =  107
%IDC_TopicOpt     =  201
%IDC_NoteOpt      =  202
%IDC_AddName      =  203
%IDM_New          =  301
%IDM_Open         =  302
%IDM_Save         =  303
%IDM_SaveAs       =  304
%IDM_HelpTitle    =  305
%IDM_Exit         =  306
%IDM_AddTopic     =  401
%IDM_AddNote      =  402
%IDM_Rename       =  403
%IDM_ChangeLevel  =  404
%IDM_Move         =  405
%IDM_MoveTo       =  406
%IDM_DeleteItem   =  407
%IDM_Print        =  408
%IDM_ExpandAll    =  409
%IDM_Collapse     =  410
%IDM_Undo         =  501
%IDM_Cut          =  502
%IDM_Copy         =  503
%IDM_Paste        =  504
%IDM_Delete       =  505
%IDM_SelAll       =  506
%IDM_Tab          =  507
%IDM_TabSpaces    =  521
%IDM_WordWrap     =  522
%IDM_Find         =  601        
%IDM_Next         =  602                      
%IDM_Prev         =  603
%IDM_Esc          =  604
%IDM_OtherPane    =  605                          
%IDM_ProgHelp     =  701 
%IDM_RunHelp      =  702                       
%IDM_About        =  703

type editOption
   tabSpaces as long                                                        
   nWordWrap as long                                                    
end type

GLOBAL hDlg, hFont, numItems, numTree, fileChanged, nWordWrap, lastWordwrap AS LONG
GLOBAL hMenu, hFileMenu, hItemMenu, hEditMenu, hSrchMenu, hHelpMenu as long
GLOBAL hTextbox, hTitle, hIndex, editLabel, origTextboxProc AS LONG
global hTreeviewMenu, hTextboxMenu, initSrch, tabSpaces, inputOpt AS LONG 
global wholeWord, doNotNotify, redoTreeHandles as long
GLOBAL dataFolder, iniFile, thisFile, helpTitle AS STRING
GLOBAL titles(), texts(), dataFiles() AS STRING 
global treeLevel(), treeHandles() as long
global editOpt() as editOption                                        
 
global debugVal as long
                                

sub dbug(hDlg as long, opt byval s as string)      
   dialog set text hDlg, s
   sleep 2000
   dialog set text hDlg, ""
end sub

'-------------------------------------------------------------------------------------------------------------
'Notes:
'   original strategy: numItems increases with adds, never decreased even at safe 
'   later strategy   : numItems recomputed at save as acual number of tree items
'
'   numItems = number of items in texts(), titles(), treeLevel(), editOpt()... never less than first opened
'   numTree  = current number of tree items in treeHandles()... will be less than numItems with deletions                                         
'
'   texts()  = help contents (stored sequentially)
'   titles() = help titles (stored sequentially)                                                
'   treeLevel()  = 0 if item i is a topic
'                = 1 if item i is a note                                   
'                  (stored sequentially)
'
'   dataFolder = CSIDL_COMMON_APPDATA when program folder is CSIDL_COMMON_PROGRAMS
'              = program folder, otherwise
'
'   wordWrap =  1 on
'            =  0 off
'

                                         